%
% convering a full-dimensional PCC
%     A : face vectors (column vectors) (should be simplified)
%     n : dimension
%     U : span vectors (column vectors)
%     E : null-space bases
%     V : proper cone span vectors
%
function [ U, E, V ] = PCC_convert_full( A, n )
    %A = PCC_simplify(A);
    %n = size(A,1); % dimension
    [E,B] = null_and_complement_null(A');
    m = size(B,2); % dim of proper cone space
    alpha = zeros(m,size(A,2));
    for k=1:size(A,2)
        alpha(:,k) = (A(:,k)'*B)';
    end
    beta = PCC_convert_proper_cone(alpha);
    V = zeros(n,size(beta,2));
    for k=1:size(beta,2)
        V(:,k) = B*beta(:,k);
    end
    
    U = [ E, -sum(E,2), V ];
end
